@@ -9,7 +9,7 @@ if TYPE_CHECKING:
 
 
 class AwesomeProfile(XorgProfile):
-	def __init__(self):
+	def __init__(self) -> None:
 		super().__init__('Awesome', ProfileType.WindowMgr, description='')
 
 	@property
@@ -28,7 +28,7 @@ class AwesomeProfile(XorgProfile):
 			'xsel',
 		]
 
-	def install(self, install_session: 'Installer'):
+	def install(self, install_session: 'Installer') -> None:
 		super().install(install_session)
 
 		# TODO: Copy a full configuration to ~/.config/awesome/rc.lua instead.
@@ -60,4 +60,4 @@ class AwesomeProfile(XorgProfile):
 		xinitrc_data += 'exec awesome\n'
 
 		with open(f"{install_session.target}/etc/X11/xinit/xinitrc", 'w') as xinitrc:
-			xinitrc.write(xinitrc_data)
\ No newline at end of file
+			xinitrc.write(xinitrc_data)
