@@ -6,8 +6,9 @@ from archinstall.default_profiles.xorg import XorgProfile
 if TYPE_CHECKING:
 	_: Any
 
+
 class CosmicProfile(XorgProfile):
-	def __init__(self):
+	def __init__(self) -> None:
 		super().__init__('cosmic-epoch', ProfileType.DesktopEnv, description='', advanced=True)
 
 	@property
