@@ -8,7 +8,7 @@ if TYPE_CHECKING:
 
 
 class GnomeProfile(XorgProfile):
-	def __init__(self):
+	def __init__(self) -> None:
 		super().__init__('Gnome', ProfileType.DesktopEnv, description='')
 
 	@property
