@@ -16,7 +16,7 @@ class SeatAccess(Enum):
 
 
 class HyprlandProfile(XorgProfile):
-	def __init__(self):
+	def __init__(self) -> None:
 		super().__init__('Hyprland', ProfileType.DesktopEnv, description='')
 
 		self.custom_settings = {'seat_access': None}
@@ -47,7 +47,7 @@ class HyprlandProfile(XorgProfile):
 			return [pref]
 		return []
 
-	def _ask_seat_access(self):
+	def _ask_seat_access(self) -> None:
 		# need to activate seat service and add to seat group
 		title = str(_('Hyprland needs access to your seat (collection of hardware devices i.e. keyboard, mouse, etc)'))
 		title += str(_('\n\nChoose an option to give Hyprland access to your hardware'))
@@ -64,5 +64,5 @@ class HyprlandProfile(XorgProfile):
 	def do_on_select(self):
 		self._ask_seat_access()
 
-	def install(self, install_session: 'Installer'):
+	def install(self, install_session: 'Installer') -> None:
 		super().install(install_session)
