@@ -6,8 +6,9 @@ from archinstall.default_profiles.xorg import XorgProfile
 if TYPE_CHECKING:
 	_: Any
 
+
 class PlasmaProfile(XorgProfile):
-	def __init__(self):
+	def __init__(self) -> None:
 		super().__init__('KDE Plasma', ProfileType.DesktopEnv, description='')
 
 	@property
