@@ -4,7 +4,7 @@ from archinstall.default_profiles.profile import Profile, ProfileType
 
 
 class SshdProfile(Profile):
-	def __init__(self):
+	def __init__(self) -> None:
 		super().__init__(
 			'sshd',
 			ProfileType.ServerType
