@@ -12,12 +12,14 @@ class XorgProfile(Profile):
 		name: str = 'Xorg',
 		profile_type: ProfileType = ProfileType.Xorg,
 		description: str = str(_('Installs a minimal system as well as xorg and graphics drivers.')),
+		advanced: bool = False
 	):
 		super().__init__(
 			name,
 			profile_type,
 			description=description,
-			support_gfx_driver=True
+			support_gfx_driver=True,
+			advanced=advanced
 		)
 
 	def preview_text(self) -> Optional[str]:
