@@ -32,7 +32,7 @@ class FilesystemHandler:
 		self._disk_config = disk_config
 		self._enc_config = enc_conf
 
-	def perform_filesystem_operations(self, show_countdown: bool = True):
+	def perform_filesystem_operations(self, show_countdown: bool = True) -> None:
 		if self._disk_config.config_type == DiskLayoutType.Pre_mount:
 			debug('Disk layout configuration is set to pre-mount, not performing any operations')
 			return
@@ -90,7 +90,7 @@ class FilesystemHandler:
 		self,
 		partitions: List[PartitionModification],
 		device_path: Path
-	):
+	) -> None:
 		"""
 		Format can be given an overriding path, for instance /dev/null to test
 		the formatting functionality and in essence the support for the given filesystem.
@@ -122,7 +122,7 @@ class FilesystemHandler:
 			part_mod.partuuid = lsblk_info.partuuid
 			part_mod.uuid = lsblk_info.uuid
 
-	def _validate_partitions(self, partitions: List[PartitionModification]):
+	def _validate_partitions(self, partitions: List[PartitionModification]) -> None:
 		checks = {
 			# verify that all partitions have a path set (which implies that they have been created)
 			lambda x: x.dev_path is None: ValueError('When formatting, all partitions must have a path set'),
@@ -138,7 +138,7 @@ class FilesystemHandler:
 			if found is not None:
 				raise exc
 
-	def perform_lvm_operations(self):
+	def perform_lvm_operations(self) -> None:
 		info('Setting up LVM config...')
 
 		if not self._disk_config.lvm_config:
@@ -153,7 +153,7 @@ class FilesystemHandler:
 			self._setup_lvm(self._disk_config.lvm_config)
 			self._format_lvm_vols(self._disk_config.lvm_config)
 
-	def _setup_lvm_encrypted(self, lvm_config: LvmConfiguration, enc_config: DiskEncryption):
+	def _setup_lvm_encrypted(self, lvm_config: LvmConfiguration, enc_config: DiskEncryption) -> None:
 		if enc_config.encryption_type == EncryptionType.LvmOnLuks:
 			enc_mods = self._encrypt_partitions(enc_config, lock_after_create=False)
 
@@ -175,7 +175,7 @@ class FilesystemHandler:
 
 			self._safely_close_lvm(lvm_config)
 
-	def _safely_close_lvm(self, lvm_config: LvmConfiguration):
+	def _safely_close_lvm(self, lvm_config: LvmConfiguration) -> None:
 		for vg in lvm_config.vol_groups:
 			for vol in vg.volumes:
 				device_handler.lvm_vol_change(vol, False)
@@ -186,7 +186,7 @@ class FilesystemHandler:
 		self,
 		lvm_config: LvmConfiguration,
 		enc_mods: Dict[PartitionModification, Luks2] = {}
-	):
+	) -> None:
 		self._lvm_create_pvs(lvm_config, enc_mods)
 
 		for vg in lvm_config.vol_groups:
@@ -233,7 +233,7 @@ class FilesystemHandler:
 		self,
 		lvm_config: LvmConfiguration,
 		enc_vols: Dict[LvmVolume, Luks2] = {}
-	):
+	) -> None:
 		for vol in lvm_config.get_all_volumes():
 			if enc_vol := enc_vols.get(vol, None):
 				if not enc_vol.mapper_dev:
@@ -253,7 +253,7 @@ class FilesystemHandler:
 		self,
 		lvm_config: LvmConfiguration,
 		enc_mods: Dict[PartitionModification, Luks2] = {}
-	):
+	) -> None:
 		pv_paths: Set[Path] = set()
 
 		for vg in lvm_config.vol_groups:
@@ -328,7 +328,7 @@ class FilesystemHandler:
 
 		return enc_mods
 
-	def _lvm_vol_handle_e2scrub(self, vol_gp: LvmVolumeGroup):
+	def _lvm_vol_handle_e2scrub(self, vol_gp: LvmVolumeGroup) -> None:
 		# from arch wiki:
 		# If a logical volume will be formatted with ext4, leave at least 256 MiB
 		# free space in the volume group to allow using e2scrub
