@@ -97,7 +97,7 @@ class Installer:
 	def __enter__(self) -> 'Installer':
 		return self
 
-	def __exit__(self, exc_type, exc_val, exc_tb):
+	def __exit__(self, exc_type, exc_val, exc_tb) -> bool:
 		if exc_type is not None:
 			error(exc_val)
 
@@ -126,15 +126,15 @@ class Installer:
 			self.sync_log_to_install_medium()
 			return False
 
-	def remove_mod(self, mod: str):
+	def remove_mod(self, mod: str) -> None:
 		if mod in self._modules:
 			self._modules.remove(mod)
 
-	def append_mod(self, mod: str):
+	def append_mod(self, mod: str) -> None:
 		if mod not in self._modules:
 			self._modules.append(mod)
 
-	def _verify_service_stop(self):
+	def _verify_service_stop(self) -> None:
 		"""
 		Certain services might be running that affects the system during installation.
 		One such service is "reflector.service" which updates /etc/pacman.d/mirrorlist
@@ -177,7 +177,7 @@ class Installer:
 		while self._service_state('archlinux-keyring-wkd-sync.service') not in ('dead', 'failed', 'exited'):
 			time.sleep(1)
 
-	def _verify_boot_part(self):
+	def _verify_boot_part(self) -> None:
 		"""
 		Check that mounted /boot device has at minimum size for installation
 		The reason this check is here is to catch pre-mounted device configuration and potentially
@@ -221,7 +221,7 @@ class Installer:
 		# mount all regular partitions
 		self._mount_partition_layout(luks_handlers)
 
-	def _mount_partition_layout(self, luks_handlers: Dict[Any, Luks2]):
+	def _mount_partition_layout(self, luks_handlers: Dict[Any, Luks2]) -> None:
 		debug('Mounting partition layout')
 
 		# do not mount any PVs part of the LVM configuration
@@ -252,7 +252,7 @@ class Installer:
 				else:
 					self._mount_partition(part_mod)
 
-	def _mount_lvm_layout(self, luks_handlers: Dict[Any, Luks2] = {}):
+	def _mount_lvm_layout(self, luks_handlers: Dict[Any, Luks2] = {}) -> None:
 		lvm_config = self._disk_config.lvm_config
 
 		if not lvm_config:
@@ -284,7 +284,7 @@ class Installer:
 			if part_mod.mapper_name and part_mod.dev_path
 		}
 
-	def _import_lvm(self):
+	def _import_lvm(self) -> None:
 		lvm_config = self._disk_config.lvm_config
 
 		if not lvm_config:
@@ -311,7 +311,7 @@ class Installer:
 			if vol.mapper_name and vol.dev_path
 		}
 
-	def _mount_partition(self, part_mod: disk.PartitionModification):
+	def _mount_partition(self, part_mod: disk.PartitionModification) -> None:
 		# it would be none if it's btrfs as the subvolumes will have the mountpoints defined
 		if part_mod.mountpoint and part_mod.dev_path:
 			target = self.target / part_mod.relative_mountpoint
@@ -324,7 +324,7 @@ class Installer:
 				part_mod.mount_options
 			)
 
-	def _mount_lvm_vol(self, volume: disk.LvmVolume):
+	def _mount_lvm_vol(self, volume: disk.LvmVolume) -> None:
 		if volume.fs_type != disk.FilesystemType.Btrfs:
 			if volume.mountpoint and volume.dev_path:
 				target = self.target / volume.relative_mountpoint
@@ -333,7 +333,7 @@ class Installer:
 		if volume.fs_type == disk.FilesystemType.Btrfs and volume.dev_path:
 			self._mount_btrfs_subvol(volume.dev_path, volume.btrfs_subvols, volume.mount_options)
 
-	def _mount_luks_partition(self, part_mod: disk.PartitionModification, luks_handler: Luks2):
+	def _mount_luks_partition(self, part_mod: disk.PartitionModification, luks_handler: Luks2) -> None:
 		if part_mod.fs_type != disk.FilesystemType.Btrfs:
 			if part_mod.mountpoint and luks_handler.mapper_dev:
 				target = self.target / part_mod.relative_mountpoint
@@ -342,7 +342,7 @@ class Installer:
 		if part_mod.fs_type == disk.FilesystemType.Btrfs and luks_handler.mapper_dev:
 			self._mount_btrfs_subvol(luks_handler.mapper_dev, part_mod.btrfs_subvols, part_mod.mount_options)
 
-	def _mount_luks_volume(self, volume: disk.LvmVolume, luks_handler: Luks2):
+	def _mount_luks_volume(self, volume: disk.LvmVolume, luks_handler: Luks2) -> None:
 		if volume.fs_type != disk.FilesystemType.Btrfs:
 			if volume.mountpoint and luks_handler.mapper_dev:
 				target = self.target / volume.relative_mountpoint
@@ -356,7 +356,7 @@ class Installer:
 		dev_path: Path,
 		subvolumes: List[disk.SubvolumeModification],
 		mount_options: List[str] = []
-	):
+	) -> None:
 		for subvol in subvolumes:
 			mountpoint = self.target / subvol.relative_mountpoint
 			mount_options = mount_options + [f'subvol={subvol.name}']
@@ -374,7 +374,7 @@ class Installer:
 				# so we won't need any keyfile generation atm
 				pass
 
-	def _generate_key_files_partitions(self):
+	def _generate_key_files_partitions(self) -> None:
 		for part_mod in self._disk_encryption.partitions:
 			gen_enc_file = self._disk_encryption.should_generate_encryption_file(part_mod)
 
@@ -396,7 +396,7 @@ class Installer:
 						self._disk_encryption.encryption_password
 					)
 
-	def _generate_key_file_lvm_volumes(self):
+	def _generate_key_file_lvm_volumes(self) -> None:
 		for vol in self._disk_encryption.lvm_volumes:
 			gen_enc_file = self._disk_encryption.should_generate_encryption_file(vol)
 
@@ -432,7 +432,7 @@ class Installer:
 
 		return True
 
-	def add_swapfile(self, size='4G', enable_resume=True, file='/swapfile'):
+	def add_swapfile(self, size: str = '4G', enable_resume: bool = True, file: str = '/swapfile') -> None:
 		if file[:1] != '/':
 			file = f"/{file}"
 		if len(file.strip()) <= 0 or file == '/':
@@ -457,7 +457,7 @@ class Installer:
 	def post_install_check(self, *args: str, **kwargs: str) -> List[str]:
 		return [step for step, flag in self.helper_flags.items() if flag is False]
 
-	def set_mirrors(self, mirror_config: MirrorConfiguration, on_target: bool = False):
+	def set_mirrors(self, mirror_config: MirrorConfiguration, on_target: bool = False) -> None:
 		"""
 		Set the mirror configuration for the installation.
 
@@ -496,7 +496,7 @@ class Installer:
 			with local_mirrorlist_conf.open('w') as fp:
 				fp.write(mirrorlist_config)
 
-	def genfstab(self, flags: str = '-pU'):
+	def genfstab(self, flags: str = '-pU') -> None:
 		fstab_path = self.target / "etc" / "fstab"
 		info(f"Updating {fstab_path}")
 
@@ -510,7 +510,7 @@ class Installer:
 			fp.write(gen_fstab)
 
 		if not fstab_path.is_file():
-			raise RequirementError(f'Could not create fstab file')
+			raise RequirementError('Could not create fstab file')
 
 		for plugin in plugins.values():
 			if hasattr(plugin, 'on_genfstab'):
@@ -521,7 +521,7 @@ class Installer:
 			for entry in self._fstab_entries:
 				fp.write(f'{entry}\n')
 
-	def set_hostname(self, hostname: str):
+	def set_hostname(self, hostname: str) -> None:
 		with open(f'{self.target}/etc/hostname', 'w') as fh:
 			fh.write(hostname + '\n')
 
@@ -634,7 +634,7 @@ class Installer:
 	def drop_to_shell(self) -> None:
 		subprocess.check_call(f"/usr/bin/arch-chroot {self.target}", shell=True)
 
-	def configure_nic(self, nic: Nic):
+	def configure_nic(self, nic: Nic) -> None:
 		conf = nic.as_systemd_config()
 
 		for plugin in plugins.values():
@@ -665,7 +665,7 @@ class Installer:
 						# This function will be called after minimal_installation()
 						# as a hook for post-installs. This hook is only needed if
 						# base is not installed yet.
-						def post_install_enable_iwd_service(*args: str, **kwargs: str):
+						def post_install_enable_iwd_service(*args: str, **kwargs: str) -> None:
 							self.enable_service('iwd')
 
 						self.post_base_install.append(post_install_enable_iwd_service)
@@ -707,10 +707,11 @@ class Installer:
 				if plugin.on_mkinitcpio(self):
 					return True
 
-		with open(f'{self.target}/etc/mkinitcpio.conf', 'w') as mkinit:
-			mkinit.write(f"MODULES=({' '.join(self._modules)})\n")
-			mkinit.write(f"BINARIES=({' '.join(self._binaries)})\n")
-			mkinit.write(f"FILES=({' '.join(self._files)})\n")
+		with open(f'{self.target}/etc/mkinitcpio.conf', 'r+') as mkinit:
+			content = mkinit.read()
+			content = re.sub("\nMODULES=(.*)", f"\nMODULES=({' '.join(self._modules)})", content)
+			content = re.sub("\nBINARIES=(.*)", f"\nBINARIES=({' '.join(self._binaries)})", content)
+			content = re.sub("\nFILES=(.*)", f"\nFILES=({' '.join(self._files)})", content)
 
 			if not self._disk_encryption.hsm_device:
 				# For now, if we don't use HSM we revert to the old
@@ -720,7 +721,9 @@ class Installer:
 				# * sd-vconsole -> keymap
 				self._hooks = [hook.replace('systemd', 'udev').replace('sd-vconsole', 'keymap consolefont') for hook in self._hooks]
 
-			mkinit.write(f"HOOKS=({' '.join(self._hooks)})\n")
+			content = re.sub("\nHOOKS=(.*)", f"\nHOOKS=({' '.join(self._hooks)})", content)
+			mkinit.seek(0)
+			mkinit.write(content)
 
 		try:
 			SysCommand(f'/usr/bin/arch-chroot {self.target} mkinitcpio {" ".join(flags)}', peek_output=True)
@@ -736,7 +739,7 @@ class Installer:
 				return vendor.get_ucode()
 		return None
 
-	def _handle_partition_installation(self):
+	def _handle_partition_installation(self) -> None:
 		pvs = []
 		if self._disk_config.lvm_config:
 			pvs = self._disk_config.lvm_config.get_all_pvs()
@@ -773,7 +776,7 @@ class Installer:
 						if 'encrypt' not in self._hooks:
 							self._hooks.insert(self._hooks.index('filesystems'), 'encrypt')
 
-	def _handle_lvm_installation(self):
+	def _handle_lvm_installation(self) -> None:
 		if not self._disk_config.lvm_config:
 			return
 
@@ -888,9 +891,9 @@ class Installer:
 			if hasattr(plugin, 'on_install'):
 				plugin.on_install(self)
 
-	def setup_swap(self, kind: str = 'zram'):
+	def setup_swap(self, kind: str = 'zram') -> None:
 		if kind == 'zram':
-			info(f"Setting up swap on zram")
+			info("Setting up swap on zram")
 			self.pacman.strap('zram-generator')
 
 			# We could use the default example below, but maybe not the best idea: https://github.com/archlinux/archinstall/pull/678#issuecomment-962124813
@@ -903,7 +906,7 @@ class Installer:
 
 			self._zram_enabled = True
 		else:
-			raise ValueError(f"Archinstall currently only supports setting up swap on zram")
+			raise ValueError("Archinstall currently only supports setting up swap on zram")
 
 	def _get_efi_partition(self) -> Optional[disk.PartitionModification]:
 		for layout in self._disk_config.device_modifications:
@@ -1050,7 +1053,7 @@ class Installer:
 		root: disk.PartitionModification | disk.LvmVolume,
 		efi_partition: Optional[disk.PartitionModification],
 		uki_enabled: bool = False
-	):
+	) -> None:
 		debug('Installing systemd bootloader')
 
 		self.pacman.strap('efibootmgr')
@@ -1148,7 +1151,7 @@ class Installer:
 		boot_partition: disk.PartitionModification,
 		root: disk.PartitionModification | disk.LvmVolume,
 		efi_partition: Optional[disk.PartitionModification]
-	):
+	) -> None:
 		debug('Installing grub bootloader')
 
 		self.pacman.strap('grub')  # no need?
@@ -1233,7 +1236,7 @@ class Installer:
 		boot_partition: disk.PartitionModification,
 		efi_partition: Optional[disk.PartitionModification],
 		root: disk.PartitionModification | disk.LvmVolume
-	):
+	) -> None:
 		debug('Installing limine bootloader')
 
 		self.pacman.strap('limine')
@@ -1304,7 +1307,7 @@ Exec = /bin/sh -c "{hook_command}"
 		for kernel in self.kernels:
 			for variant in ('', '-fallback'):
 				entry = [
-					f'protocol: linux',
+					'protocol: linux',
 					f'kernel_path: boot():/vmlinuz-{kernel}',
 					f'kernel_cmdline: {kernel_params}',
 					f'module_path: boot():/initramfs-{kernel}{variant}.img',
@@ -1323,7 +1326,7 @@ Exec = /bin/sh -c "{hook_command}"
 		boot_partition: disk.PartitionModification,
 		root: disk.PartitionModification | disk.LvmVolume,
 		uki_enabled: bool = False
-	):
+	) -> None:
 		debug('Installing efistub bootloader')
 
 		self.pacman.strap('efibootmgr')
@@ -1372,7 +1375,7 @@ Exec = /bin/sh -c "{hook_command}"
 		self,
 		root: disk.PartitionModification | disk.LvmVolume,
 		efi_partition: Optional[disk.PartitionModification]
-	):
+	) -> None:
 		if not efi_partition or not efi_partition.mountpoint:
 			raise ValueError(f'Could not detect ESP at mountpoint {self.target}')
 
@@ -1462,7 +1465,7 @@ Exec = /bin/sh -c "{hook_command}"
 			case Bootloader.Limine:
 				self._add_limine_bootloader(boot_partition, efi_partition, root)
 
-	def add_additional_packages(self, packages: Union[str, List[str]]) -> bool:
+	def add_additional_packages(self, packages: Union[str, List[str]]) -> None:
 		return self.pacman.strap(packages)
 
 	def enable_sudo(self, entity: str, group: bool = False):
@@ -1495,7 +1498,7 @@ Exec = /bin/sh -c "{hook_command}"
 		# Guarantees sudoer conf file recommended perms
 		os.chmod(Path(rule_file_name), 0o440)
 
-	def create_users(self, users: Union[User, List[User]]):
+	def create_users(self, users: Union[User, List[User]]) -> None:
 		if not isinstance(users, list):
 			users = [users]
 
@@ -1617,7 +1620,7 @@ Exec = /bin/sh -c "{hook_command}"
 				except SysCallError as err:
 					raise ServiceException(f"Unable to set locale '{language}' for X11: {err}")
 		else:
-			info(f'X11-Keyboard language was not changed from default (no language specified)')
+			info('X11-Keyboard language was not changed from default (no language specified)')
 
 		return True
 
