@@ -15,24 +15,25 @@ from .exceptions import SysCallError, DownloadTimeout
 from .output import error, info
 from .pacman import Pacman
 
+
 class DownloadTimer():
 	'''
 	Context manager for timing downloads with timeouts.
 	'''
-	def __init__(self, timeout=5):
+	def __init__(self, timeout: int = 5):
 		'''
 		Args:
 			timeout:
 				The download timeout in seconds. The DownloadTimeout exception
 				will be raised in the context after this many seconds.
 		'''
-		self.time = None
-		self.start_time = None
+		self.time: Optional[float] = None
+		self.start_time: Optional[float] = None
 		self.timeout = timeout
 		self.previous_handler = None
-		self.previous_timer = None
+		self.previous_timer: Optional[int] = None
 
-	def raise_timeout(self, signl, frame):
+	def raise_timeout(self, signl, frame) -> None:
 		'''
 		Raise the DownloadTimeout exception.
 		'''
@@ -40,13 +41,13 @@ class DownloadTimer():
 
 	def __enter__(self):
 		if self.timeout > 0:
-			self.previous_handler = signal.signal(signal.SIGALRM, self.raise_timeout)
+			self.previous_handler = signal.signal(signal.SIGALRM, self.raise_timeout)  # type: ignore[assignment]
 			self.previous_timer = signal.alarm(self.timeout)
 
 		self.start_time = time.time()
 		return self
 
-	def __exit__(self, typ, value, traceback):
+	def __exit__(self, typ, value, traceback) -> None:
 		if self.start_time:
 			time_delta = time.time() - self.start_time
 			signal.alarm(0)
@@ -65,14 +66,14 @@ class DownloadTimer():
 		self.start_time = None
 
 
-def get_hw_addr(ifname :str) -> str:
+def get_hw_addr(ifname: str) -> str:
 	import fcntl
 	s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
 	ret = fcntl.ioctl(s.fileno(), 0x8927, struct.pack('256s', bytes(ifname, 'utf-8')[:15]))
 	return ':'.join('%02x' % b for b in ret[18:24])
 
 
-def list_interfaces(skip_loopback :bool = True) -> Dict[str, str]:
+def list_interfaces(skip_loopback: bool = True) -> Dict[str, str]:
 	interfaces = {}
 
 	for index, iface in socket.if_nameindex():
@@ -136,7 +137,7 @@ def fetch_data_from_url(url: str, params: Optional[Dict] = None) -> str:
 		raise ValueError(f'Unable to fetch data from url: {url}')
 
 
-def calc_checksum(icmp_packet):
+def calc_checksum(icmp_packet) -> int:
 	# Calculate the ICMP checksum
 	checksum = 0
 	for i in range(0, len(icmp_packet), 2):
@@ -147,10 +148,11 @@ def calc_checksum(icmp_packet):
 
 	checksum = (checksum >> 16) + (checksum & 0xFFFF)
 	checksum = ~checksum & 0xFFFF
-	
+
 	return checksum
 
-def build_icmp(payload):
+
+def build_icmp(payload: bytes) -> bytes:
 	# Define the ICMP Echo Request packet
 	icmp_packet = struct.pack('!BBHHH', 8, 0, 0, 0, 1) + payload
 
@@ -158,11 +160,12 @@ def build_icmp(payload):
 
 	return struct.pack('!BBHHH', 8, 0, checksum, 0, 1) + payload
 
-def ping(hostname, timeout=5):
+
+def ping(hostname, timeout=5) -> int:
 	watchdog = select.epoll()
 	started = time.time()
 	random_identifier = f'archinstall-{random.randint(1000, 9999)}'.encode()
-	
+
 	# Create a raw socket (requires root, which should be fine on archiso)
 	icmp_socket = socket.socket(socket.AF_INET, socket.SOCK_RAW, socket.IPPROTO_ICMP)
 	watchdog.register(icmp_socket, select.EPOLLIN | select.EPOLLHUP)
@@ -190,4 +193,4 @@ def ping(hostname, timeout=5):
 			break
 
 	icmp_socket.close()
-	return latency
\ No newline at end of file
+	return latency
